@@ -1,11 +1,11 @@
 import logging
 
-from .client import flow_client, AccessAPI
+from .client import flow_client, AccessAPI, entities
 from .script import Script
 from .exceptions import PySDKError, NotCadenceValueError
 from .signer import SignAlgo, HashAlgo, InMemorySigner, Signer
 from .account_key import AccountKey
-from .templates import create_account_template
+from .templates import create_account_template, ContractTemplates
 from .tx import Tx, ProposalKey, TxSignature, TransactionStatus
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
