@@ -16,3 +16,11 @@ class NotCadenceValueError(PySDKError):
         return NotCadenceValueError(
             f"Value {value} is not a cadence value. Cadence value expected."
         )
+
+
+class CadenceEncodingError(PySDKError):
+    pass
+
+
+class CadenceIncorrectTypeError(PySDKError):
+    pass
